/*
 * SPDX-License-Identifier: BSD-2-Clause
 *
 * Copyright (C) 2018, 2019 embedded brains GmbH
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

/*
 * This file must be compatible to general purpose POSIX system, e.g. Linux,
 * FreeBSD.  It may be used for utility programs.
 */

#if HAVE_CONFIG_H
#include "config.h"
#endif

#include <rtems/recorddata.h>

#include <stddef.h>

static const char * const event_text[] = {
  [ RTEMS_RECORD_EMPTY ] = "EMPTY",
  [ RTEMS_RECORD_VERSION ] = "VERSION",
  [ RTEMS_RECORD_ACCEPT ] = "ACCEPT",
  [ RTEMS_RECORD_BIND ] = "BIND",
  [ RTEMS_RECORD_BUFFER ] = "BUFFER",
  [ RTEMS_RECORD_CHOWN ] = "CHOWN",
  [ RTEMS_RECORD_CLOSE ] = "CLOSE",
  [ RTEMS_RECORD_CONNECT ] = "CONNECT",
  [ RTEMS_RECORD_COUNT ] = "COUNT",
  [ RTEMS_RECORD_ETHER_INPUT ] = "ETHER_INPUT",
  [ RTEMS_RECORD_ETHER_OUTPUT ] = "ETHER_OUTPUT",
  [ RTEMS_RECORD_FCHMOD ] = "FCHMOD",
  [ RTEMS_RECORD_FCNTL ] = "FCNTL",
  [ RTEMS_RECORD_FDATASYNC ] = "FDATASYNC",
  [ RTEMS_RECORD_FREQUENCY ] = "FREQUENCY",
  [ RTEMS_RECORD_FSTAT ] = "FSTAT",
  [ RTEMS_RECORD_FSYNC ] = "FSYNC",
  [ RTEMS_RECORD_FTRUNCATE ] = "FTRUNCATE",
  [ RTEMS_RECORD_GIT_HASH ] = "GIT_HASH",
  [ RTEMS_RECORD_HEAD ] = "HEAD",
  [ RTEMS_RECORD_HEAP_ALLOC ] = "HEAP_ALLOC",
  [ RTEMS_RECORD_HEAP_FREE ] = "HEAP_FREE",
  [ RTEMS_RECORD_HEAP_SIZE ] = "HEAP_SIZE",
  [ RTEMS_RECORD_HEAP_USAGE ] = "HEAP_USAGE",
  [ RTEMS_RECORD_INTERUPT_BEGIN ] = "INTERUPT_BEGIN",
  [ RTEMS_RECORD_INTERUPT_END ] = "INTERUPT_END",
  [ RTEMS_RECORD_INTERUPT_INSTALL ] = "INTERUPT_INSTALL",
  [ RTEMS_RECORD_INTERUPT_REMOVE ] = "INTERUPT_REMOVE",
  [ RTEMS_RECORD_IOCTL ] = "IOCTL",
  [ RTEMS_RECORD_IP6_INPUT ] = "IP6_INPUT",
  [ RTEMS_RECORD_IP6_OUTPUT ] = "IP6_OUTPUT",
  [ RTEMS_RECORD_IP_INPUT ] = "IP_INPUT",
  [ RTEMS_RECORD_IP_OUTPUT ] = "IP_OUTPUT",
  [ RTEMS_RECORD_KEVENT ] = "KEVENT",
  [ RTEMS_RECORD_KQUEUE ] = "KQUEUE",
  [ RTEMS_RECORD_LENGTH ] = "LENGTH",
  [ RTEMS_RECORD_LINK ] = "LINK",
  [ RTEMS_RECORD_LSEEK ] = "LSEEK",
  [ RTEMS_RECORD_MKNOD ] = "MKNOD",
  [ RTEMS_RECORD_MMAP ] = "MMAP",
  [ RTEMS_RECORD_MOUNT ] = "MOUNT",
  [ RTEMS_RECORD_OPEN ] = "OPEN",
  [ RTEMS_RECORD_OVERFLOW ] = "OVERFLOW",
  [ RTEMS_RECORD_PAGE_ALLOC ] = "PAGE_ALLOC",
  [ RTEMS_RECORD_PAGE_FREE ] = "PAGE_FREE",
  [ RTEMS_RECORD_POLL ] = "POLL",
  [ RTEMS_RECORD_PROCESSOR ] = "PROCESSOR",
  [ RTEMS_RECORD_PROCESSOR_MAXIMUM ] = "PROCESSOR_MAXIMUM",
  [ RTEMS_RECORD_READ ] = "READ",
  [ RTEMS_RECORD_READLINK ] = "READLINK",
  [ RTEMS_RECORD_READV ] = "READV",
  [ RTEMS_RECORD_RECV ] = "RECV",
  [ RTEMS_RECORD_RECVFROM ] = "RECVFROM",
  [ RTEMS_RECORD_RECVMSG ] = "RECVMSG",
  [ RTEMS_RECORD_RENAME ] = "RENAME",
  [ RTEMS_RECORD_RTEMS_BARRIER_CREATE ] = "RTEMS_BARRIER_CREATE",
  [ RTEMS_RECORD_RTEMS_BARRIER_DELETE ] = "RTEMS_BARRIER_DELETE",
  [ RTEMS_RECORD_RTEMS_BARRIER_RELEASE ] = "RTEMS_BARRIER_RELEASE",
  [ RTEMS_RECORD_RTEMS_BARRIER_WAIT ] = "RTEMS_BARRIER_WAIT",
  [ RTEMS_RECORD_RTEMS_EVENT_RECEIVE ] = "RTEMS_EVENT_RECEIVE",
  [ RTEMS_RECORD_RTEMS_EVENT_SEND ] = "RTEMS_EVENT_SEND",
  [ RTEMS_RECORD_RTEMS_EVENT_SYSTEM_RECEIVE ] = "RTEMS_EVENT_SYSTEM_RECEIVE",
  [ RTEMS_RECORD_RTEMS_EVENT_SYSTEM_SEND ] = "RTEMS_EVENT_SYSTEM_SEND",
  [ RTEMS_RECORD_RTEMS_MESSAGE_QUEUE_BROADCAST ] = "RTEMS_MESSAGE_QUEUE_BROADCAST",
  [ RTEMS_RECORD_RTEMS_MESSAGE_QUEUE_CREATE ] = "RTEMS_MESSAGE_QUEUE_CREATE",
  [ RTEMS_RECORD_RTEMS_MESSAGE_QUEUE_DELETE ] = "RTEMS_MESSAGE_QUEUE_DELETE",
  [ RTEMS_RECORD_RTEMS_MESSAGE_QUEUE_FLUSH ] = "RTEMS_MESSAGE_QUEUE_FLUSH",
  [ RTEMS_RECORD_RTEMS_MESSAGE_QUEUE_RECEIVE ] = "RTEMS_MESSAGE_QUEUE_RECEIVE",
  [ RTEMS_RECORD_RTEMS_MESSAGE_QUEUE_SEND ] = "RTEMS_MESSAGE_QUEUE_SEND",
  [ RTEMS_RECORD_RTEMS_MESSAGE_QUEUE_URGENT ] = "RTEMS_MESSAGE_QUEUE_URGENT",
  [ RTEMS_RECORD_RTEMS_PARTITION_CREATE ] = "RTEMS_PARTITION_CREATE",
  [ RTEMS_RECORD_RTEMS_PARTITION_DELETE ] = "RTEMS_PARTITION_DELETE",
  [ RTEMS_RECORD_RTEMS_PARTITION_GET_BUFFER ] = "RTEMS_PARTITION_GET_BUFFER",
  [ RTEMS_RECORD_RTEMS_PARTITION_RETURN_BUFFER ] = "RTEMS_PARTITION_RETURN_BUFFER",
  [ RTEMS_RECORD_RTEMS_RATE_MONOTONIC_CANCEL ] = "RTEMS_RATE_MONOTONIC_CANCEL",
  [ RTEMS_RECORD_RTEMS_RATE_MONOTONIC_CREATE ] = "RTEMS_RATE_MONOTONIC_CREATE",
  [ RTEMS_RECORD_RTEMS_RATE_MONOTONIC_DELETE ] = "RTEMS_RATE_MONOTONIC_DELETE",
  [ RTEMS_RECORD_RTEMS_RATE_MONOTONIC_PERIOD ] = "RTEMS_RATE_MONOTONIC_PERIOD",
  [ RTEMS_RECORD_RTEMS_SEMAPHORE_CREATE ] = "RTEMS_SEMAPHORE_CREATE",
  [ RTEMS_RECORD_RTEMS_SEMAPHORE_DELETE ] = "RTEMS_SEMAPHORE_DELETE",
  [ RTEMS_RECORD_RTEMS_SEMAPHORE_FLUSH ] = "RTEMS_SEMAPHORE_FLUSH",
  [ RTEMS_RECORD_RTEMS_SEMAPHORE_OBTAIN ] = "RTEMS_SEMAPHORE_OBTAIN",
  [ RTEMS_RECORD_RTEMS_SEMAPHORE_RELEASE ] = "RTEMS_SEMAPHORE_RELEASE",
  [ RTEMS_RECORD_RTEMS_TIMER_CANCEL ] = "RTEMS_TIMER_CANCEL",
  [ RTEMS_RECORD_RTEMS_TIMER_CREATE ] = "RTEMS_TIMER_CREATE",
  [ RTEMS_RECORD_RTEMS_TIMER_DELETE ] = "RTEMS_TIMER_DELETE",
  [ RTEMS_RECORD_RTEMS_TIMER_FIRE_AFTER ] = "RTEMS_TIMER_FIRE_AFTER",
  [ RTEMS_RECORD_RTEMS_TIMER_FIRE_WHEN ] = "RTEMS_TIMER_FIRE_WHEN",
  [ RTEMS_RECORD_RTEMS_TIMER_RESET ] = "RTEMS_TIMER_RESET",
  [ RTEMS_RECORD_RTEMS_TIMER_SERVER_FIRE_AFTER ] = "RTEMS_TIMER_SERVER_FIRE_AFTER",
  [ RTEMS_RECORD_RTEMS_TIMER_SERVER_FIRE_WHEN ] = "RTEMS_TIMER_SERVER_FIRE_WHEN",
  [ RTEMS_RECORD_SELECT ] = "SELECT",
  [ RTEMS_RECORD_SEND ] = "SEND",
  [ RTEMS_RECORD_SENDMSG ] = "SENDMSG",
  [ RTEMS_RECORD_SENDTO ] = "SENDTO",
  [ RTEMS_RECORD_SOCKET ] = "SOCKET",
  [ RTEMS_RECORD_STATVFS ] = "STATVFS",
  [ RTEMS_RECORD_SYMLINK ] = "SYMLINK",
  [ RTEMS_RECORD_TAIL ] = "TAIL",
  [ RTEMS_RECORD_TCP_INPUT ] = "TCP_INPUT",
  [ RTEMS_RECORD_TCP_OUTPUT ] = "TCP_OUTPUT",
  [ RTEMS_RECORD_THREAD_BEGIN ] = "THREAD_BEGIN",
  [ RTEMS_RECORD_THREAD_CREATE ] = "THREAD_CREATE",
  [ RTEMS_RECORD_THREAD_DELETE ] = "THREAD_DELETE",
  [ RTEMS_RECORD_THREAD_EXIT ] = "THREAD_EXIT",
  [ RTEMS_RECORD_THREAD_EXITTED ] = "THREAD_EXITTED",
  [ RTEMS_RECORD_THREAD_ID ] = "THREAD_ID",
  [ RTEMS_RECORD_THREAD_PRIO_CURRENT_HIGH ] = "THREAD_PRIO_CURRENT_HIGH",
  [ RTEMS_RECORD_THREAD_PRIO_CURRENT_LOW ] = "THREAD_PRIO_CURRENT_LOW",
  [ RTEMS_RECORD_THREAD_PRIO_REAL_HIGH ] = "THREAD_PRIO_REAL_HIGH",
  [ RTEMS_RECORD_THREAD_PRIO_REAL_LOW ] = "THREAD_PRIO_REAL_LOW",
  [ RTEMS_RECORD_THREAD_QUEUE_ENQUEUE ] = "THREAD_QUEUE_ENQUEUE",
  [ RTEMS_RECORD_THREAD_QUEUE_ENQUEUE_STICKY ] = "THREAD_QUEUE_ENQUEUE_STICKY",
  [ RTEMS_RECORD_THREAD_QUEUE_EXTRACT ] = "THREAD_QUEUE_EXTRACT",
  [ RTEMS_RECORD_THREAD_QUEUE_SURRENDER ] = "THREAD_QUEUE_SURRENDER",
  [ RTEMS_RECORD_THREAD_QUEUE_SURRENDER_STICKY ] = "THREAD_QUEUE_SURRENDER_STICKY",
  [ RTEMS_RECORD_THREAD_RESTART ] = "THREAD_RESTART",
  [ RTEMS_RECORD_THREAD_STACK_CURRENT ] = "THREAD_STACK_CURRENT",
  [ RTEMS_RECORD_THREAD_STACK_SIZE ] = "THREAD_STACK_SIZE",
  [ RTEMS_RECORD_THREAD_STACK_USAGE ] = "THREAD_STACK_USAGE",
  [ RTEMS_RECORD_THREAD_START ] = "THREAD_START",
  [ RTEMS_RECORD_THREAD_STATE_CLEAR ] = "THREAD_STATE_CLEAR",
  [ RTEMS_RECORD_THREAD_STATE_SET ] = "THREAD_STATE_SET",
  [ RTEMS_RECORD_THREAD_SWITCH_IN ] = "THREAD_SWITCH_IN",
  [ RTEMS_RECORD_THREAD_SWITCH_OUT ] = "THREAD_SWITCH_OUT",
  [ RTEMS_RECORD_THREAD_TERMINATE ] = "THREAD_TERMINATE",
  [ RTEMS_RECORD_UDP_INPUT ] = "UDP_INPUT",
  [ RTEMS_RECORD_UDP_OUTPUT ] = "UDP_OUTPUT",
  [ RTEMS_RECORD_UMA_ALLOC_PTR ] = "UMA_ALLOC_PTR",
  [ RTEMS_RECORD_UMA_ALLOC_ZONE ] = "UMA_ALLOC_ZONE",
  [ RTEMS_RECORD_UMA_FREE_PTR ] = "UMA_FREE_PTR",
  [ RTEMS_RECORD_UMA_FREE_ZONE ] = "UMA_FREE_ZONE",
  [ RTEMS_RECORD_UNLINK ] = "UNLINK",
  [ RTEMS_RECORD_UNMOUNT ] = "UNMOUNT",
  [ RTEMS_RECORD_UPTIME_HIGH ] = "UPTIME_HIGH",
  [ RTEMS_RECORD_UPTIME_LOW ] = "UPTIME_LOW",
  [ RTEMS_RECORD_WORKSPACE_ALLOC ] = "WORKSPACE_ALLOC",
  [ RTEMS_RECORD_WORKSPACE_FREE ] = "WORKSPACE_FREE",
  [ RTEMS_RECORD_WORKSPACE_SIZE ] = "WORKSPACE_SIZE",
  [ RTEMS_RECORD_WORKSPACE_USAGE ] = "WORKSPACE_USAGE",
  [ RTEMS_RECORD_WRITE ] = "WRITE",
  [ RTEMS_RECORD_WRITEV ] = "WRITEV"
};

const char *rtems_record_event_text( rtems_record_event event )
{
  size_t n;

  n = event;

  if ( n < sizeof( event_text ) / sizeof( event_text[ 0 ] ) ) {
    return event_text[ n ];
  }

  return NULL;
}
